@@ -77,11 +77,12 @@ class BlockTimestampGraph(object):
 
     def get_first_point(self):
         # Ignore the genesis block as its timestamp is 0
-        return self.get_point(1)
+        return Point(1, 1581035055)
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
-        return Point(6781175, 1596548400) #TODO: query status to get latest
+#        return Point(2182936, 1596642898) #TODO: query status to get latest
+        return Point(2182936, 1596632400) #TODO: query status to get latest
 
     def get_point(self, x):
 #        return block_to_point(self._theta_provider.eth.getBlock(x))
@@ -93,6 +94,7 @@ class BlockTimestampGraph(object):
         if (len(blocks) == 0) :
             self.logger.info("failed to get block : %d\n", x)
             return Point(x, -1)
+        self.logger.info("succeed to get block : %d, timestamp is %s \n", x, blocks[0].timestamp)
         return block_to_point(blocks[0])
 
 
